# frozen_string_literal: true

# Redmine - project management software
# Copyright (C) 2006-2021  Jean-Philippe Lang
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

require File.expand_path('../../../test_helper', __FILE__)

class Redmine::ApiTest::TrackersTest < Redmine::ApiTest::Base
  fixtures :trackers

  test "GET /trackers.xml should return trackers" do
    get '/trackers.xml'

    assert_response :success
    assert_equal 'application/xml', @response.media_type

    assert_select 'trackers[type=array] tracker id', :text => '2' do
      assert_select '~ name', :text => 'Feature request'
      assert_select '~ description', :text => 'Description for Feature request tracker'
    end
  end
end
